/* -*- mode: c -*-
 * $Id: fib2.c,v 1.4 2006/05/25 18:31:14 lattner Exp $
 * http://www.bagley.org/~doug/shootout/
 */

int atoi(char *);
#include <stdio.h>

unsigned long
fib(unsigned long n) {
    if (n < 2)
	return(1);
    else
	return(fib(n-2) + fib(n-1));
}

int
main(int argc, char *argv[]) {
    int N = ((argc == 2) ? atoi(argv[1]) : 43);
    printf("%ld\n", fib(N));
    return(0);
}
